@@ -29,14 +29,11 @@
 # ==============================================================================
 
 from dimp import *
+from .plugins import *
 
 from .notification import Notification, Observer, NotificationCenter
 from .notification import ApplePushNotificationService
 
-from .nlp import Dialog, ChatBot, Tuling, XiaoI
-
-from .network import NetMsgHead, NetMsg
-from .network import Session, SessionServer
 from .network import CASubject, CAValidity, CAData, CertificateAuthority
 from .network import ServiceProvider, Station, Robot
 
@@ -73,14 +70,22 @@ __all__ = [
     'SignKey', 'VerifyKey', 'EncryptKey', 'DecryptKey',
     'SymmetricKey', 'PrivateKey', 'PublicKey',
 
+    # data
+    'BaseCoder',
+    'Base64', 'Base58', 'Hex',
+    'Digest',
+    'MD5', 'SHA1', 'SHA256', 'RIPEMD160',
+    'md5', 'sha1', 'sha256', 'ripemd160',
+
     # entity
-    'NetworkID', 'Address', 'ID', 'Meta', 'Profile',
+    'NetworkID', 'MetaVersion',
+    'Address', 'ID', 'Meta', 'Profile',
     'Entity', 'User', 'Group',
 
     # delegate
     'EntityDataSource', 'UserDataSource', 'GroupDataSource',
 
-    'ANYONE', 'EVERYONE',
+    'ANYONE', 'EVERYONE', 'ANYWHERE', 'EVERYWHERE',
 
     #
     #   DaoKeDao
@@ -123,12 +128,7 @@ __all__ = [
     'Notification', 'Observer', 'NotificationCenter',
     'ApplePushNotificationService',
 
-    # NLP
-    'Dialog', 'ChatBot', 'Tuling', 'XiaoI',
-
     # network
-    'NetMsgHead', 'NetMsg',
-    'Session', 'SessionServer',
     'CASubject', 'CAValidity', 'CAData', 'CertificateAuthority',
     'ServiceProvider', 'Station', 'Robot',
 
