@@ -39,7 +39,7 @@
 from typing import Optional
 
 from dimp import ID
-from dimp import InstantMessage
+from dimp import ReliableMessage
 from dimp import Content
 from dimp import GroupCommand, ExpelCommand
 
@@ -70,7 +70,7 @@ class ExpelCommandProcessor(GroupCommandProcessor):
     #
     #   main
     #
-    def process(self, content: Content, sender: ID, msg: InstantMessage) -> Optional[Content]:
+    def process(self, content: Content, sender: ID, msg: ReliableMessage) -> Optional[Content]:
         assert isinstance(content, ExpelCommand), 'group command error: %s' % content
         facebook = self.facebook
         group: ID = facebook.identifier(content.group)
