@@ -37,7 +37,7 @@
 from typing import Optional
 
 from dimp import ID, Meta
-from dimp import InstantMessage
+from dimp import ReliableMessage
 from dimp import Content
 from dimp import TextContent, Command, MetaCommand
 
@@ -72,7 +72,7 @@ class MetaCommandProcessor(CommandProcessor):
     #
     #   main
     #
-    def process(self, content: Content, sender: ID, msg: InstantMessage) -> Optional[Content]:
+    def process(self, content: Content, sender: ID, msg: ReliableMessage) -> Optional[Content]:
         assert isinstance(content, MetaCommand), 'command error: %s' % content
         identifier = self.facebook.identifier(content.identifier)
         meta = content.meta
