@@ -39,7 +39,7 @@
 from typing import Optional
 
 from dimp import ID
-from dimp import InstantMessage
+from dimp import ReliableMessage
 from dimp import Content, TextContent
 from dimp import GroupCommand, QueryCommand
 
@@ -51,7 +51,7 @@ class QueryCommandProcessor(GroupCommandProcessor):
     #
     #   main
     #
-    def process(self, content: Content, sender: ID, msg: InstantMessage) -> Optional[Content]:
+    def process(self, content: Content, sender: ID, msg: ReliableMessage) -> Optional[Content]:
         assert isinstance(content, QueryCommand), 'group command error: %s' % content
         facebook = self.facebook
         group: ID = facebook.identifier(content.group)
