@@ -38,11 +38,11 @@
 import os
 from typing import Optional
 
-from mkm.dos import JSONFile
-
 from dimp import User
 from dimp import KeyCache
 
+from .dos import JSONFile
+
 
 class KeyStore(KeyCache):
 
