@@ -39,7 +39,7 @@ import weakref
 from abc import abstractmethod
 from typing import Optional, Union
 
-from dimp import SymmetricKey, ID, Meta, User
+from dimp import SymmetricKey, EncryptKey, ID, Meta, User
 from dimp import InstantMessage, SecureMessage, ReliableMessage
 from dimp import Content, FileContent
 from dimp import Transceiver
@@ -99,7 +99,7 @@ class Messenger(Transceiver, ConnectionDelegate):
             assert isinstance(barrack, Facebook), 'messenger delegate error: %s' % barrack
         return barrack
 
-    def __select(self, receiver: ID) -> Optional[User]:
+    def _select(self, receiver: ID) -> Optional[User]:
         facebook = self.facebook
         users = facebook.local_users
         if users is None or len(users) == 0:
@@ -124,7 +124,7 @@ class Messenger(Transceiver, ConnectionDelegate):
 
     def __trim(self, msg: SecureMessage) -> Optional[SecureMessage]:
         receiver = self.facebook.identifier(msg.envelope.receiver)
-        user = self.__select(receiver=receiver)
+        user = self._select(receiver=receiver)
         if user is None:
             # current users not match
             msg = None
@@ -169,7 +169,7 @@ class Messenger(Transceiver, ConnectionDelegate):
     #
     #   InstantMessageDelegate
     #
-    def encrypt_content(self, content: Content, key: dict, msg: InstantMessage) -> bytes:
+    def serialize_content(self, content: Content, key: dict, msg: InstantMessage) -> bytes:
         password = SymmetricKey(key=key)
         assert password == key, 'irregular symmetric key: %s' % key
         # check attachment for File/Image/Audio/Video message content before
@@ -180,27 +180,27 @@ class Messenger(Transceiver, ConnectionDelegate):
             if url is not None:
                 content.url = url
                 content.data = None
-        return super().encrypt_content(content=content, key=password, msg=msg)
+        return super().serialize_content(content=content, key=password, msg=msg)
 
-    def encrypt_key(self, key: dict, receiver: str, msg: InstantMessage) -> Optional[bytes]:
+    def encrypt_key(self, data: bytes, receiver: str, msg: InstantMessage) -> Optional[bytes]:
         facebook = self.facebook
         to = facebook.identifier(receiver)
         pk = facebook.public_key_for_encryption(identifier=to)
         if pk is None:
             meta = facebook.meta(identifier=to)
-            if meta is None:
+            if meta is None or not isinstance(meta.key, EncryptKey):
                 # save this message in a queue waiting receiver's meta response
                 self.suspend_message(msg=msg)
                 # raise LookupError('failed to get encrypt key for receiver: %s' % receiver)
                 return None
-        return super().encrypt_key(key=key, receiver=receiver, msg=msg)
+        return super().encrypt_key(data=data, receiver=receiver, msg=msg)
 
     #
     #   SecureMessageDelegate
     #
-    def decrypt_content(self, data: bytes, key: dict, msg: SecureMessage) -> Optional[Content]:
+    def deserialize_content(self, data: bytes, key: dict, msg: SecureMessage) -> Optional[Content]:
         password = SymmetricKey(key=key)
-        content = super().decrypt_content(data=data, key=password, msg=msg)
+        content = super().deserialize_content(data=data, key=password, msg=msg)
         if content is None:
             return None
         # check attachment for File/Image/Audio/Video message content after
@@ -221,7 +221,7 @@ class Messenger(Transceiver, ConnectionDelegate):
     #
     #   Send message
     #
-    def send_content(self, content: Content, receiver: ID, callback: Callback=None, split: bool=True) -> bool:
+    def send_content(self, content: Content, receiver: ID, callback: Callback=None, split: bool=False) -> bool:
         """
         Send content to receiver
 
@@ -237,7 +237,7 @@ class Messenger(Transceiver, ConnectionDelegate):
         return self.send_message(msg=i_msg, callback=callback, split=split)
 
     def send_message(self, msg: Union[InstantMessage, ReliableMessage],
-                     callback: Callback=None, split: bool=True) -> bool:
+                     callback: Callback=None, split: bool=False) -> bool:
         """
         Send instant message (encrypt and sign) onto DIM network
 
@@ -328,7 +328,7 @@ class Messenger(Transceiver, ConnectionDelegate):
             # no message received
             return None
         # 2. process message
-        r_msg = self.process_reliable(msg=r_msg)
+        r_msg = self.process_message(msg=r_msg)
         if r_msg is None:
             # nothing to response
             return None
@@ -337,43 +337,41 @@ class Messenger(Transceiver, ConnectionDelegate):
 
     # TODO: override to check broadcast message before calling it
     # TODO: override to deliver to the receiver when catch exception "receiver error ..."
-    def process_reliable(self, msg: ReliableMessage) -> Optional[ReliableMessage]:
+    def process_message(self, msg: ReliableMessage) -> Optional[ReliableMessage]:
         # 1. verify message
         s_msg = self.verify_message(msg=msg)
         if s_msg is None:
             # waiting for sender's meta if not exists
             return None
         # 2. process message
-        s_msg = self.process_secure(msg=s_msg)
+        s_msg = self.__process_secure(secure=s_msg, msg=msg)
         if s_msg is None:
             # nothing to respond
             return None
         # 3. sign message
         return self.sign_message(msg=s_msg)
 
-    def process_secure(self, msg: SecureMessage) -> Optional[SecureMessage]:
+    def __process_secure(self, secure: SecureMessage, msg: ReliableMessage) -> Optional[SecureMessage]:
         # 1. decrypt message
-        i_msg = self.decrypt_message(msg=msg)
+        i_msg = self.decrypt_message(msg=secure)
         if i_msg is None:
             # cannot decrypt this message, not for you?
             # delivering message to other receiver?
             return None
         # 2. process message
-        i_msg = self.process_instant(msg=i_msg)
+        i_msg = self.__process_instant(instant=i_msg, msg=msg)
         if i_msg is None:
             # nothing to respond
             return None
         # 3. encrypt message
         return self.encrypt_message(msg=i_msg)
 
-    # TODO: override to check group
-    # TODO: override to filter the response
-    def process_instant(self, msg: InstantMessage) -> Optional[InstantMessage]:
+    def __process_instant(self, instant: InstantMessage, msg: ReliableMessage) -> Optional[InstantMessage]:
         facebook = self.facebook
         sender = facebook.identifier(string=msg.envelope.sender)
         # process content from sender
-        res = self.__cpu.process(content=msg.content, sender=sender, msg=msg)
-        if not self.save_message(msg=msg):
+        res = self.process_content(content=instant.content, sender=sender, msg=msg)
+        if not self.save_message(msg=instant):
             # error
             return None
         if res is None:
@@ -381,11 +379,17 @@ class Messenger(Transceiver, ConnectionDelegate):
             return None
         # check receiver
         receiver = facebook.identifier(msg.envelope.receiver)
-        user = self.__select(receiver=receiver)
+        user = self._select(receiver=receiver)
         assert user is not None, 'receiver error: %s' % receiver
         # pack message
         return InstantMessage.new(content=res, sender=user.identifier, receiver=sender)
 
+    # TODO: override to check group
+    # TODO: override to filter the response
+    def process_content(self, content: Content, sender: ID, msg: ReliableMessage) -> Optional[Content]:
+        # call CPU to process it
+        return self.__cpu.process(content=content, sender=sender, msg=msg)
+
 
 class MessageCallback(CompletionHandler):
 
